#[non_exhaustive]pub enum AttributeValue<'a> {
String(Cow<'a, str>),
Bool(bool),
None,
}Expand description
An AttributeValue represents the value of an attribute in a document.
An attribute value can be a string, a boolean, or nothing
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
String(Cow<'a, str>)
A string attribute value.
Bool(bool)
A boolean attribute value. false means it is unset.
None
No value (or it was unset)