InlineNode

Enum InlineNode 

#[non_exhaustive]
pub enum InlineNode<'a> {
Show 16 variants PlainText(Plain<'a>), RawText(Raw<'a>), VerbatimText(Verbatim<'a>), BoldText(Bold<'a>), ItalicText(Italic<'a>), MonospaceText(Monospace<'a>), HighlightText(Highlight<'a>), SubscriptText(Subscript<'a>), SuperscriptText(Superscript<'a>), CurvedQuotationText(CurvedQuotation<'a>), CurvedApostropheText(CurvedApostrophe<'a>), StandaloneCurvedApostrophe(StandaloneCurvedApostrophe), LineBreak(LineBreak), InlineAnchor(Anchor<'a>), Macro(InlineMacro<'a>), CalloutRef(CalloutRef),
}
An InlineNode represents an inline node in a document.

An inline node is a structural element in a document that can contain other inline nodes and are only valid within a paragraph (a leaf).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PlainText(Plain<'a>)



RawText(Raw<'a>)



VerbatimText(Verbatim<'a>)



BoldText(Bold<'a>)



ItalicText(Italic<'a>)



MonospaceText(Monospace<'a>)



HighlightText(Highlight<'a>)



SubscriptText(Subscript<'a>)



SuperscriptText(Superscript<'a>)



CurvedQuotationText(CurvedQuotation<'a>)



CurvedApostropheText(CurvedApostrophe<'a>)



StandaloneCurvedApostrophe(StandaloneCurvedApostrophe)



LineBreak(LineBreak)



InlineAnchor(Anchor<'a>)



Macro(InlineMacro<'a>)



CalloutRef(CalloutRef)

Callout reference marker in verbatim content: <1>, <.>, etc.

Implementations

Source

impl InlineNode<'_>

pub fn location(&self) -> &Location

Returns the source location of this inline node.