strip_quotes

Function strip_quotes 

pub fn strip_quotes(s: &str) -> &str
Strip surrounding single or double quotes from a string.

Attribute values in AsciiDoc can be quoted with either single or double quotes. This function strips the outermost matching quotes from both ends.