#[non_exhaustive]pub struct Autolink<'a> {
pub url: Source<'a>,
pub bracketed: bool,
pub location: Location,
}Expand description
An Autolink represents an inline autolink in a document.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: Source<'a>bracketed: boolWhether the autolink was written with angle brackets (e.g., <user@example.com>).
When true, the renderer should preserve the brackets in the output.
location: LocationTrait Implementations
impl<'a> StructuralPartialEq for Autolink<'a>