DocumentAttributes

Struct DocumentAttributes 

pub struct DocumentAttributes<'a>(/* private fields */);
Document-level attributes with universal defaults.

These attributes apply to the entire document and include defaults for admonition captions, TOC settings, structural settings, etc.

Use DocumentAttributes::default() to get a map with universal defaults applied.

Implementations

Source

impl<'a> DocumentAttributes<'a>

pub fn iter( &self, ) -> impl Iterator<Item = (&AttributeName<'a>, &AttributeValue<'a>)>

Iterate over all attributes.

pub fn is_empty(&self) -> bool

Check if the attribute map is empty.

pub fn insert(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)

Insert a new attribute.

NOTE: This will NOT overwrite an existing attribute with the same name.

pub fn set(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)

Set an attribute, overwriting any existing value.

pub fn get(&self, name: &str) -> Option<&AttributeValue<'a>>

Get an attribute value by name.

pub fn contains_key(&self, name: &str) -> bool

Check if an attribute exists.

pub fn remove(&mut self, name: &str) -> Option<AttributeValue<'a>>

Remove an attribute by name.

pub fn merge(&mut self, other: Self)

Merge another attribute map into this one.

pub fn get_string(&self, name: &str) -> Option<Cow<'a, str>>

Helper to get a string value.

Strips surrounding quotes from the value if present (parser quirk workaround).

pub fn to_static(&self) -> DocumentAttributes<'static>

Clone the attributes into an independent 'static copy. Used by converters that cache document attributes on a processor whose lifetime is independent of the document being rendered.

pub fn into_static(self) -> DocumentAttributes<'static>

Consume the attributes, producing an independent 'static copy.