pub struct ElementAttributes<'a>(/* private fields */);Expand description
Element-level attributes (for blocks, sections, etc.).
These attributes are specific to individual elements and start empty.
Use ElementAttributes::default() to get an empty attribute map.
Implementations
Sourceimpl<'a> ElementAttributes<'a>
impl<'a> ElementAttributes<'a>
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&AttributeName<'a>, &AttributeValue<'a>)>
pub fn iter( &self, ) -> impl Iterator<Item = (&AttributeName<'a>, &AttributeValue<'a>)>
Iterate over all attributes.
Sourcepub fn insert(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)
pub fn insert(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)
Insert a new attribute.
NOTE: This will NOT overwrite an existing attribute with the same name.
Sourcepub fn set(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)
pub fn set(&mut self, name: AttributeName<'a>, value: AttributeValue<'a>)
Set an attribute, overwriting any existing value.
Sourcepub fn get(&self, name: &str) -> Option<&AttributeValue<'a>>
pub fn get(&self, name: &str) -> Option<&AttributeValue<'a>>
Get an attribute value by name.
Sourcepub fn contains_key(&self, name: &str) -> bool
pub fn contains_key(&self, name: &str) -> bool
Check if an attribute exists.
Sourcepub fn remove(&mut self, name: &str) -> Option<AttributeValue<'a>>
pub fn remove(&mut self, name: &str) -> Option<AttributeValue<'a>>
Remove an attribute by name.
Sourcepub fn into_static(self) -> ElementAttributes<'static>
pub fn into_static(self) -> ElementAttributes<'static>
Convert all borrowed content to owned, producing 'static lifetime attributes.