#[non_exhaustive]pub struct Image<'a> {
pub title: Title<'a>,
pub source: Source<'a>,
pub metadata: BlockMetadata<'a>,
pub location: Location,
}Expand description
An Image represents an image block in a document.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Title<'a>source: Source<'a>metadata: BlockMetadata<'a>location: LocationImplementations
Sourceimpl<'a> Image<'a>
impl<'a> Image<'a>
Sourcepub fn new(source: Source<'a>, location: Location) -> Self
pub fn new(source: Source<'a>, location: Location) -> Self
Create a new image with the given source and location.
Sourcepub fn with_title(self, title: Title<'a>) -> Self
pub fn with_title(self, title: Title<'a>) -> Self
Set the title.
Sourcepub fn with_metadata(self, metadata: BlockMetadata<'a>) -> Self
pub fn with_metadata(self, metadata: BlockMetadata<'a>) -> Self
Set the metadata.