pub struct Plain<'a> {
pub content: &'a str,
pub location: Location,
pub escaped: bool,
}Expand description
A Plain represents a plain text section in a document.
This is the most basic form of text in a document.
Fields
content: &'a strlocation: Locationescaped: boolTrue if content originated from an escaped pattern (e.g., \^2^).
When true, the converter should not re-parse for quotes.