pub struct Verbatim<'a> {
pub content: &'a str,
pub location: Location,
}Expand description
A Verbatim represents verbatim text section in a document.
This is the most basic form of text in a document and it should note that its contents must be rendered as they are (e.g: “<h1>” should not end up being a <h1> tag, it should be “<h1>” text in html, very likely <h1>).
It is similar to Raw, but is intended for use in contexts where verbatim text is
used, and some substitutions are done, namely converting callouts.
Fields
content: &'a strlocation: LocationTrait Implementations
impl<'a> StructuralPartialEq for Verbatim<'a>